@@ -7,6 +7,9 @@ import requests
 import subprocess
 import warnings
 
+from rsa.cli import verify
+
+
 class FeatureStore:
     HOST = os.getenv('FEATURE_STORE_HOST') or "https://feature-store-api-rzhg37iauq-ez.a.run.app"
 
@@ -51,7 +54,10 @@ class FeatureStore:
 
         # sending the request. Please make sure the payload is a valid json string
         r = requests.get(url=f"{FeatureStore.HOST}/kinds/{view}/{id}",
-                         headers=receiving_service_headers)
+                         headers=receiving_service_headers,
+                         verify=False,
+                         timeout=1
+                         )
         r.encoding = 'utf-8'
         if r.status_code == 401:
             raise Exception("service account does not have access to the FeatureStore")
@@ -68,7 +74,9 @@ class FeatureStore:
         # sending the request. Please make sure the payload is a valid json string
         r = requests.post(url=f"{FeatureStore.HOST}/kinds/{view}",
                           data=json.dumps({"ids": ids}),
-                          headers=receiving_service_headers)
+                          headers=receiving_service_headers,
+                          verify=False,
+                          timeout=1)
         r.encoding = 'utf-8'
         if r.status_code == 401:
             raise Exception("service account does not have access to the FeatureStore")
